import names
import json
from typing import Optional, List, Set
from string import ascii_uppercase

from django.core.management.base import BaseCommand

from mainapp.models import Member, Team, SectionValidator


# TODO: refactor this file like create_teams_fixtures.py


# SECTION_LETTERS = ascii_uppercase


# def get_next_available_section(member: Member, section_validator: SectionValidator) -> Optional[str]:
#     """Returns the next available section for a member."""
#     member_sections = member.sections.all().values_list('name', flat=True)
#     used_sections = set(member_sections)

#     if not member_sections:
#         return "A"

#     used_sections = sorted(used_sections)

#     last_section = member_sections[-1]
#     last_section_index = SECTION_LETTERS.index(last_section)

#     for i in range(last_section_index + 1, len(SECTION_LETTERS)):
#         section = SECTION_LETTERS[i]
#         if section_validator.is_valid_section(section) and section not in used_sections:
#             return section

#     for i in range(last_section_index - 1, -1, -1):
#         section = SECTION_LETTERS[i]
#         if section_validator.is_valid_section(section) and section not in used_sections:
#             return section

#     return None



class Command(BaseCommand):
    help = "Creates a fixture with randomly generated Member objects"

    def add_arguments(self, parser):
        parser.add_argument("num_members", type=int)

    def handle(self, *args, **options):
        num_members = options["num_members"]
        teams = Team.objects.all()
        if not teams:
            print("No teams found. Please create some teams first.")
            return

        members = []
        for team in teams:
            for _ in range(num_members):
                first_name = names.get_first_name()
                last_name = names.get_last_name()
                member = Member.objects.create(first_name=first_name, last_name=last_name, team=team)
                members.append(member)

        self.stdout.write(self.style.SUCCESS(f"Created {num_members} members."))

        # create a members fixture file
        members_fixture = []
        for member in members:
            member_fixture = {
                "model": "mainapp.member",
                "pk": member.pk,
                "fields": {
                    "first_name": member.first_name,
                    "last_name": member.last_name,
                    "team": member.team_id,
                    "peg_number": member.peg_number,
                }
            }
            members_fixture.append(member_fixture)

        with open("src/mainapp/fixtures/members_fixture.json", "w") as f:
            f.write(json.dumps(members_fixture, indent=2))
            self.stdout.write(self.style.SUCCESS("Created members_fixture.json."))
